Struct WpImageDescriptionReferenceV1
pub struct WpImageDescriptionReferenceV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
Reference to an image description
This object is a reference to an image description. This interface is frozen at version 1 to allow other protocols to create wp_image_description_v1 objects.
The wp_color_manager_v1.get_image_description request can be used to retrieve the underlying image description.
This interface has no events.
Implementations
impl WpImageDescriptionReferenceV1
impl WpImageDescriptionReferenceV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the reference
Destroy this object. This has no effect on the referenced image description.